@@ -4,6 +4,7 @@ from dataclasses import replace
 from pvtrace.light.ray import Ray
 import functools
 import logging
+
 logger = logging.getLogger(__name__)
 
 """
@@ -23,31 +24,39 @@ circular_mask: callable
     A function which uniformly positions rays over a circle in the xy-plane. 
     Requires functools.partial to be used with the constructor (see examples).
 """
+
+
 def default_wavelength():
     return 555.0
 
+
 def default_position():
     return (0.0, 0.0, 0.0)
 
+
 def default_direction():
     return (0.0, 0.0, 1.0)
 
+
 def rectangular_mask(X, Y):
-    return (np.random.uniform(-X, X),
-            np.random.uniform(-Y, Y),
-            0.0)
+    return (np.random.uniform(-X, X), np.random.uniform(-Y, Y), 0.0)
+
 
 def circular_mask(radius: float) -> Sequence[float]:
-    rads = np.random.uniform(0, 2.0*np.pi)
+    rads = np.random.uniform(0, 2.0 * np.pi)
     r = np.sqrt(np.random.uniform()) * radius
     x = r * np.cos(rads)
     y = r * np.sin(rads)
     return (x, y, 0.0)
 
+
 def cube_mask(X, Y, Z):
-    return (np.random.uniform(-X, X),
-            np.random.uniform(-Y, Y),
-            np.random.uniform(-Z, Z))
+    return (
+        np.random.uniform(-X, X),
+        np.random.uniform(-Y, Y),
+        np.random.uniform(-Z, Z),
+    )
+
 
 class Light(object):
     """ Generic light source object which calls delegate functions to help generate rays that
@@ -92,7 +101,6 @@ class Light(object):
     required distribution of rays.
     """
 
-
     def __init__(self, wavelength=None, position=None, direction=None, name="Light"):
         """
         Returns a light source emitting along the positive z direction of the coordinate system
@@ -148,7 +156,6 @@ class Light(object):
                 position=self.position(),
                 direction=self.direction(),
                 is_alive=True,
-                source=self
+                source=self.name,
             )
             yield ray
-
